//Functional Colors
//By William Poirier and Julian Sullivan
//wjpoirier@WPI.EDU and julsullivan@WPI.EDU
//For IMGD 2900 and Perlenspiel 2.0.6

//Released under the Creative Commons License Attribution 3.0 Unported
//http://creativecommons.org/licenses/by/3.0/

// The following comment line is for JSLint. Don't remove it!


/*global PS */


//#######FUNCTIONS#########

//PLAYER.NextSquare: takes in a keyboard input, checks the data and color of the square next to the player
//relative to that keyboard input, and returns the color of the data and color of that next square in
//the global variables "PLAYER.nextColor" and "PLAYER.nextData"
//NOTE: Colors of blocks to be set by the player are checked here too.
PLAYER.NextSquare = function(key)
{
	var dir; //checks if the direction is negative or positive
	var data;
	var orientation = 0; //operate on x or y?
	
	if (key === PS.ARROW_LEFT || key === 65)
	{
		 //data of next square 
		dir = -1;
		edge = 0;
		orientation = "x";
	}
	
	else if (key === PS.ARROW_RIGHT || key === 68) 
	{	
		dir = 1;
		edge = 15;
		orientation = "x";
	}
	
	else if (key === PS.ARROW_UP || key === 87)
	{
		 //data of next square 
		dir = -1;
		edge = 0;
		orientation = "y";
	}
	
	else if (key === PS.ARROW_DOWN || key === 83)
	{	
		dir = 1;
		edge = 15;
		orientation = "y";
	}	

	if(orientation === "x")
	{
		PLAYER.nextData = PS.BeadData(PLAYER.X + dir, PLAYER.Y);
		PLAYER.nextColor = PS.BeadColor(PLAYER.X + dir, PLAYER.Y);	
	}
	
	if(orientation === "y" && PLAYER.Y < 15)
	{	PLAYER.nextData = PS.BeadData(PLAYER.X, PLAYER.Y  + dir);
		PLAYER.nextColor = PS.BeadColor(PLAYER.X, PLAYER.Y + dir);	
	}
};
//PLAYER.JumpUp: when this function is called, the player moves up for a brief ammount of time.
//called inside PS.Tick and activated in PS.Key via PLAYER.IsJumpingUp when the UP_ARROW is pressed
PLAYER.JumpUp = function()
{
		//PS.Debug("IsJumpingUp: "+ PLAYER.IsJumpingUp + "\n");
		//PS.Debug("IsFallingDown: "+ PLAYER.IsFallingDown + "\n");
	PLAYER.NextSquare(PS.ARROW_UP);
	if (PLAYER.airTime <= 3) 
	{//Make sure the player has not exceeded 3 spaces
		//############MOVING UPWARDS###############
		if (PLAYER.nextData !== "ground")
		{
			PLAYER.Y -= 1; //move player up
			PLAYER.airTime += 1; //record how long we've been in the air for
			

			PS.BeadColor(PLAYER.X, PLAYER.Y, PLAYER.COLOR);
			PS.BeadColor(PLAYER.X, PLAYER.Y + 1, GAME.BG_COLOR);
		}
		
/*		//############MOVING HORIZONTAL#############
		if (PLAYER.holding_right)
		{
			PLAYER.NextSquare(PS.ARROW_RIGHT);
			if (PLAYER.nextData !== "ground")
				PLAYER.MoveHorizontal(PS.ARROW_RIGHT);
		}
		else if (PLAYER.holding_left)
		{
			PLAYER.NextSquare(PS.ARROW_LEFT);
			if (PLAYER.nextData !== "ground")
				PLAYER.MoveHorizontal(PS.ARROW_LEFT);
		}*/
	}
	
	if (PLAYER.airTime >= 3) //if we have been in the air for more than 3 ticks...
	{
		PLAYER.IsJumpingUp = false; //don't allow jumping...
		PLAYER.IsFallingDown = true; //...because falling is being activated
	}

};

//PLAYER.MakePlayerFall: when called, the player moves down as if under the influence of gravity. 
PLAYER.MakePlayerFall = function()
{
	//PS.Debug("inside move IsFallingDown \n");	
	if (PLAYER.Y !== 15 && PS.BeadData(PLAYER.X,(PLAYER.Y + 1)) !== GAME.GROUND) //If the ground below the player is not ground...
	{	
		if (PLAYER.IsFallingDown) //...and if PLAYER.IsFallingDown is true:
		{
			//PS.Debug("inside if statements \n")
			PS.BeadColor(PLAYER.X, PLAYER.Y, GAME.BG_COLOR); //color current square the background color,
			PLAYER.Y += 1; //set the Y position to be the next one bellow,
			PLAYER.airTime -= 1; //subtract from the air time
			//PS.Debug("airTime in MakePlayerFall: " + PLAYER.airTime + "\n"); 
			PS.BeadColor(PLAYER.X, PLAYER.Y, PLAYER.COLOR);//and color the new area the player's color
			
		}
	}
	if (PLAYER.Y !== 15 && PS.BeadData(PLAYER.X,(PLAYER.Y + 1)) === GAME.GROUND) //if the data below the player is ground
		{
			//then reset all the neccesary booleans to their default value (unless you want to go through the floor)
			PLAYER.IsFallingDown = false; 
			PLAYER.IsJumpingUp = false;
			PLAYER.airTime = 0;
			PLAYER.jumpSoundOn = false;
		}
};

//PLAYER.MoveHorizontal: takes in a keyboard input.
//When called, the player will move left or right depending on whether ARROW_LEFT or ARROW_RIGHT was pressed
//Called in PS.TICK when holding_left or holding_right are set to true in PS.KEY. Therefore the player doesn't go into hyperspeed

PLAYER.MoveHorizontal = function()
{
	
	if(PLAYER.X > 0)
	{
		PLAYER.NextSquare(PS.ARROW_LEFT); //check data to the left
		if (PLAYER.holding_left && PLAYER.nextData !== "ground")
		{
			PLAYER.X -= 1;
			PS.BeadColor(PLAYER.X, PLAYER.Y, PLAYER.COLOR);
			PS.BeadColor(PLAYER.X + 1, PLAYER.Y, GAME.BG_COLOR);
		}
	}
	
	if(PLAYER.X < 15)
	{
		PLAYER.NextSquare(PS.ARROW_RIGHT); //check data to the right
		if (PLAYER.holding_right && PLAYER.nextData !== "ground")
		{
			PLAYER.X += 1;
			PS.BeadColor(PLAYER.X, PLAYER.Y, PLAYER.COLOR);
			PS.BeadColor(PLAYER.X - 1, PLAYER.Y, GAME.BG_COLOR);
		}
	}
};

//PLAYER.AbsorbColor: changes color of the PLAYER when a certain type of block is touched.
//Not to be confused with GAME.ChangeBlockColor
//This function was not used due to time constraints. However it was an interesting mechanic,
//so I still have it included if one of us decides to go back and implement our cut game elements
PLAYER.AbsorbColor = function()
{
	if (PS.BeadData(PLAYER.X, PLAYER.Y + 1) === "red")
	{
		PLAYER.COLOR = GAME.RED
	}
	else if (PS.BeadData(PLAYER.X, PLAYER.Y + 1) === "green")
	{
		PLAYER.COLOR = GAME.GREEN;
	}
	else if (PLAYER.nextData === "blue")
	{
		///bla bla bla
	}
	else if (PS.BeadData === "indigo")
	{
		///bla bla bla
	}
	
};

//PLAYER.UpSound: When the player jumps, a cresendo of xylo notes plays
PLAYER.UpSound = function()
{
	var sound = PLAYER.airTime + 8;
	sound += 1;
//	PS.Debug("sound: " + sound + "\n");

	if (sound >= 1)
		XYLO.Xylophone(sound);
};

//GAME.MoveBlocks:
//Some of our blocks are dynamic and be pushed up, IsFallingDown, left, or right.
//This function accomadates for all three directions
GAME.MoveBlocks = function()
{
	var index = 0; //represents the index of GAME.movingBlockArray
	while (index < GAME.movingBlockArray.length) //traverse through the array and operate on the neccessary parameters
	{
		
		//NOTE: the commented out code was cut due to time constraints. Please ignore it.
		
		/*if (GAME.movingBlockArray[index][2] == "up")
		{
			if (PS.BeadData(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1] - 1) == "ground")
			{
				GAME.movingBlockArray = UTIL.RemoveIndex(GAME.movingBlockArray, index);
				index -= 1;
			}
			else
			{
				PS.BeadColor(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1] - 1, GAME.movingBlockArray[index][3]);
				PS.BeadColor(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1], GAME.BG_COLOR);
				PS.BeadData(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1] - 1, "ground");
				PS.BeadData(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1], 0);
				GAME.movingBlockArray[index][1] -= 1; //Moves the position up
			}
		}*/
		if (GAME.movingBlockArray[index][2] == "down")
		{
			if (PS.BeadData(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1] + 1) == "ground") //if the next data is not ground
			{
				GAME.movingBlockArray = UTIL.RemoveIndex(GAME.movingBlockArray, index);
				index -= 1;
			}
			else //update all parameters of the array
			{
				PS.BeadColor(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1] + 1, GAME.movingBlockArray[index][3]);
				PS.BeadColor(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1], GAME.BG_COLOR);
				PS.BeadData(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1] + 1, "ground");
				PS.BeadData(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1], 0);
				
				if ((GAME.movingBlockArray[index][1] + 1) !== 15) //if we have not reached the bottom row of beads
					GAME.movingBlockArray[index][1] += 1; //Moves the position IsFallingDown
			}
		}
		/*else if (GAME.movingBlockArray[index][2] == "left")
		{
			if (PS.BeadData(GAME.movingBlockArray[index][0] - 1, GAME.movingBlockArray[index][1]) == "ground")
			{
				GAME.movingBlockArray = UTIL.RemoveIndex(GAME.movingBlockArray, index);
				index -= 1;
			}
			else
			{
				PS.BeadColor(GAME.movingBlockArray[index][0] - 1, GAME.movingBlockArray[index][1], GAME.movingBlockArray[index][3]);
				PS.BeadColor(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1], GAME.BG_COLOR);
				PS.BeadData(GAME.movingBlockArray[index][0] - 1 , GAME.movingBlockArray[index][1], "ground");
				PS.BeadData(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1], 0);
				GAME.movingBlockArray[index][0] -= 1; //Moves the position up
			}
		}
		else if (GAME.movingBlockArray[index][2] == "right")
		{
			if (PS.BeadData(GAME.movingBlockArray[index][0] + 1, GAME.movingBlockArray[index][1]) == "ground")
			{
				GAME.movingBlockArray = UTIL.RemoveIndex(GAME.movingBlockArray, index);
				index -= 1;
			}
			else
			{
				PS.BeadColor(GAME.movingBlockArray[index][0] + 1, GAME.movingBlockArray[index][1], GAME.movingBlockArray[index][3]);
				PS.BeadColor(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1], GAME.BG_COLOR);
				PS.BeadData(GAME.movingBlockArray[index][0] + 1, GAME.movingBlockArray[index][1], "ground");
				PS.BeadData(GAME.movingBlockArray[index][0], GAME.movingBlockArray[index][1], 0);
				GAME.movingBlockArray[index][0] += 1; //Moves the position up
			}
		}*/
		index += 1;
		PLAYER.jumpSoundOn = true;
	}
};

//GAME.ChangeBlockColor: takes in a the player color, the block's color, and player's direction
GAME.ChangeBlockColor = function()
{
	PS.BeadColor(PLAYER.X, PLAYER.Y + 1, GAME.DARK_GREEN);
};

//GAME.ActivateBlock: takes in an x/y position, direction of player, and a color
//When called, a bloack takes its designated action.
GAME.ActivateBlock = function()
{	
	GAME.movingBlockArray[GAME.movingBlockArray.length] = [PLAYER.X, PLAYER.Y + 1, "down", GAME.DARK_GREEN]; 
	GAME.MoveBlocks();
	//modify moving block array if the block is meant to be dynamic	
};

//GAME.BlockPropelsPlayer: When called, the player gets launched in the air
//This function was not used due to time constraints. Maybe we'll use it in a future version though.
/*GAME.BlockPropelsPlayer = function (color)
{
	PS.BeadColor(PLAYER.X, PLAYER.Y + 1, color);
	if (color === "GAME.RED")
	{
		var i = 0;
		while (i <= 8){
			PLAYER.Y -= i;
			i += 1;
		}
	}
};*/

//GAME.ResetLevel: When called, the current level is restarted. It works by setting the level counter to the previous level
//and then setting GAME.next_level to true. This way, we just restart the current level.
GAME.ResetLevel = function()
{	
	PS.BeadData(PS.ALL, PS.ALL, 0);
	GAME.level_count -= 1;
	GAME.next_level = true;
	GAME.movingBlockArray = [];
	
};

//GAME.CheckKillerPlayer:
//Kill the player if they reach the botton of the screen
GAME.CheckKillPlayer = function(){
	if ((PLAYER.Y + 1) === 16) //reset if we go beyond the playing field
	{
		PLAYER.dead = true;
		PS.AudioPlay("piano_a0");
		GAME.ResetLevel();
		//PS.Debug("Y: " + PLAYER.Y + "\n")
	}
};



// PS.Init ()
// Initializes the game
// This function normally includes a call to PS.GridSize (x, y)
// where x and y are the desired dimensions of the grid

PS.Init = function ()
{
	"use strict";

	PS.GridSize ( 16, 16 ); //the grid size in this game is restricted to 16 by 16	
	PS.BeadFlash(PS.ALL, PS.ALL, false); //There no bead flashing in this game
	PS.BeadColor(PS.ALL, PS.ALL, GAME.BG_COLOR);
	PS.BeadBorderWidth(PS.ALL, PS.ALL, 0);
	PS.StatusColor(PS.COLOR_WHITE);
	PS.GridBGColor(GAME.HTML_BG_COLOR);
		
	MAP1.Init(); //start game up at the first map/level
	//PLAYER.X = 5; //player starting X and Y positions
	//PLAYER.Y = 12;//14;

	PS.StatusText("Green Spider uses arrow keys to move.");

	PS.BeadColor(PLAYER.X, PLAYER.Y, GAME.GREEN); //player's initial color
	//PS.BeadData(PLAYER.X, PLAYER.Y, "green"); 
	
	PS.Clock(GAME.TICK_RATE); //set PS_Clock to our default tick rate

    // Put any other init code here
};

// PS.Click (x, y, data)
// This function is called whenever a bead is clicked
// It doesn't have to do anything
// x = the x-position of the bead on the grid
// y = the y-position of the bead on the grid
// data = the data value associated with this bead, 0 if none has been set

PS.Click = function (x, y, data)
{
	"use strict";
	//PS.Debug("DATA: " + PS.BeadData(x,y,data) + "\n");
	// put code here for bead clicks
};

// PS.Release (x, y, data)
// This function is called whenever a mouse button is released over a bead
// It doesn't have to do anything
// x = the x-position of the bead on the grid
// y = the y-position of the bead on the grid
// data = the data value associated with this bead, 0 if none has been set

PS.Release = function (x, y, data)
{
	"use strict";

	// Put code here for when the mouse button is released over a bead	
};

// PS.Enter (x, y, button, data)
// This function is called whenever the mouse moves over a bead
// It doesn't have to do anything
// x = the x-position of the bead on the grid
// y = the y-position of the bead on the grid
// data = the data value associated with this bead, 0 if none has been set

PS.Enter = function (x, y, data)
{
	"use strict";

	// Put code here for when the mouse enters a bead	
};

// PS.Leave (x, y, data)
// This function is called whenever the mouse moves away from a bead
// It doesn't have to do anything
// x = the x-position of the bead on the grid
// y = the y-position of the bead on the grid
// data = the data value associated with this bead, 0 if none has been set

PS.Leave = function (x, y, data)
{
	"use strict";

	// Put code here for when the mouse leaves a bead	
};

// PS.Key (key, shift, ctrl)
// This function is called whenever a key on the keyboard is pressed
// It doesn't have to do anything
// key = the ASCII code of the pressed key, or one of the following constants:
// Arrow keys = PS.ARROW_UP, PS.ARROW_DOWN, PS.ARROW_LEFT, PS.ARROW_RIGHT
// Function keys = PS.F1 through PS.F1
// shift = true if shift key is held IsFallingDown, false otherwise
// ctrl = true if control key is held IsFallingDown, false otherwise

PS.KeyDown = function (key, shift, ctrl)
{	
	"use strict";	

	if (PLAYER.X > 0 && PLAYER.X < 15) //make sure we aren't on the edges when checking the next data and color
		PLAYER.NextSquare(key); //check the data and color of the square next to the player relative to their direction/arrow key
	
	//PS.Debug("next data: " + PLAYER.nextData + "\n")
	
	if ((key === PS.ARROW_LEFT || key === 65) && PLAYER.X > 0)
		PLAYER.holding_left = true;
	
	else if ((key === PS.ARROW_RIGHT || key === 68) && PLAYER.X < 15)	
		PLAYER.holding_right = true;
	
	else if (key === PS.ARROW_UP || key === 87)	
		PLAYER.holding_up = true;
	else if (key == PS.ARROW_DOWN || key === 83)
		PLAYER.holding_down = true;
	
	//PS.Debug(PLAYER.nextColor);
	if (key === PS.ARROW_DOWN || key === 83){ //change the color of an inactive block to green
		//PLAYER.holding_down = false;
		if (PLAYER.nextColor !== GAME.GROUND_COLOR && PLAYER.nextColor !== GAME.BG_COLOR)	
			GAME.ChangeBlockColor();
		
		if (PLAYER.nextColor === GAME.DARK_GREEN){ //activate a falling block
			if (PLAYER.Y !== 14) //make sure we don't knock a block below the barrier
				GAME.ActivateBlock();
			PLAYER.IsFallingDown = true;
			PLAYER.IsJumpingUp = false;
		}
	}
		
	
	if ((key === PS.ARROW_UP || key === 87) && !PLAYER.IsFallingDown && !PLAYER.IsJumpingUp) //press up to jump
	{
		PLAYER.IsJumpingUp = true; //the jump function is now allowed to operate in PS.Tick
		PLAYER.jumpSoundOn = true;
		//PLAYER.JumpUp();
	}
		
	//Reset a level with ESC key
	if ( (key === 27) && GAME.reset_ready)
	{
		//PS.Debug("KEY1 reset ready: " + GAME.reset_ready + "\n");
		GAME.ResetLevel();
		GAME.reset_ready = false;
		//PS.Debug("KEY2 reset ready: " + GAME.reset_ready + "\n");
	}
	
	//TEMPORARY FOR DEBUG: PRESS SPACE TO SKIP LEVELS
//	if (key === 32)
//		GAME.next_level = true;
};	

// PS.KeyUp (key, shift, ctrl)
// This function is called whenever a key on the keyboard is released
// It doesn't have to do anything
// key = the ASCII code of the pressed key, or one of the following constants:
// Arrow keys = PS.ARROW_UP, PS.ARROW_DOWN, PS.ARROW_LEFT, PS.ARROW_RIGHT
// Function keys = PS.F1 through PS.F12
// shift = true if shift key is held down, false otherwise
// ctrl = true if control key is held down, false otherwise

PS.KeyUp = function (key, shift, ctrl)
{
	"use strict";
	
	GAME.reset_ready = true;
	//PS.Debug("KEYUP reset ready: " + GAME.reset_ready + "\n");

	if (key === PS.ARROW_UP || key === 87)
	{
		PLAYER.IsJumpingUp = false;
		PLAYER.IsFallingDown = true; 
	}
	
	if (key === PS.ARROW_LEFT || key === 65)
		PLAYER.holding_left = false; //reinitialze these variables every time...
	if (key === PS.ARROW_RIGHT || key === 68)
		PLAYER.holding_right = false; //...so they aren't true if JumpUp is called on its own
	if (key === PS.ARROW_UP || key === 87)
		PLAYER.holding_up = false;
	if (key === PS.ARROW_DOWN || key === 83)
		PLAYER.holding_down = false;

};

// PS.Wheel (dir)
// This function is called whenever the mouse wheel moves forward or backward
// It doesn't have to do anything
// dir = 1 if mouse wheel moves forward, -1 if backward

PS.Wheel = function (dir)
{
	"use strict";

	// Put code here for when a key is pressed	
};

// PS.Tick ()
// This function is called on every clock tick
// if a timer has been activated with a call to PS.Timer()
// It doesn't have to do anything

PS.Tick = function ()
{
	"use strict";
	
//	PS.Debug("next Y pos beginning at tick: " + (PLAYER.Y + 1) + "\n");
	
	GAME.CheckKillPlayer(); //let's make sure the player is about to die first

	if (GAME.next_level) //check to see if we are ready to go to the next level (or reset a level)
	{
				PS.BeadColor(PS.ALL, PS.ALL, GAME.BG_COLOR); //reinitialize background
		PS.BeadData(PS.ALL, PS.ALL, 0);		
		switch(GAME.level_count){ //switch to next level map
			case 0:
				MAP1.Init(); GAME.BG_COLOR = 0x73ACB9; break;		
			case 1: 
				MAP2.Init(); GAME.BG_COLOR = 0x739BB9; break;
			case 2: 
				MAP3.Init(); GAME.BG_COLOR =  0x6C7CAA; break;
			case 3:	
				MAP4.Init(); GAME.BG_COLOR = 0x6073A4; break;
			case 4:
				MAP5.Init(); GAME.BG_COLOR = 0x48577D; break;
			case 5:
				MAP6.Init(); GAME.BG_COLOR = 0x35405B; break;
			case 6:
				MAP7.Init(); GAME.BG_COLOR = 0x313C53; break;
			case 7:
				MAP8.Init(); GAME.BG_COLOR = 0x2D354B; break;
			case 8:
				MAP9.Init(); GAME.BG_COLOR = 0x22294A; break;
			case 9:
				MAP10.Init(); GAME.BG_COLOR = 0x1F2532; break;
			case 10:
				MAP11.Init(); GAME.BG_COLOR = 0x11141C; break;
			case 11:
				ENDING.Init(); GAME.BG_COLOR = 0x0E0A0F; break;
			}
		
						
		GAME.next_level = false; //reinitialze booleans
		PLAYER.dead = false;
		PLAYER.jumpSoundOn = false;
		GAME.level_count += 1; //set level_count to the now current level
	}
		
	if (GAME.movingBlockArray.length !== 0 && !PLAYER.dead) //have a dynamic block move
		GAME.MoveBlocks();		
	
	if (PLAYER.holding_left || PLAYER.holding_right) //pressing left or right
		PLAYER.MoveHorizontal(); //have the player move either left or right (checked inside here)
				
	var AlreadyFell = false; //checks if the player has already started to fall
	if (PLAYER.IsJumpingUp)	 //have the player start moving up if they held down the up arrow
		PLAYER.JumpUp();
	
	else if (PLAYER.IsFallingDown && !PLAYER.dead) //have the player start falling when they let go of up
	{
		PLAYER.jumpSoundOn
		PLAYER.MakePlayerFall();
		AlreadyFell = true;
	}
		
	if (PLAYER.Y < 15)
		PLAYER.NextSquare(PS.ARROW_DOWN);//checks the data below player
	
	if (!PLAYER.IsJumpingUp && PLAYER.nextData !== "ground" && !AlreadyFell && !PLAYER.dead) //fall down when there is no ground below
	{
		PLAYER.IsFallingDown = true;
		PLAYER.IsJumpingUp = false;
		PLAYER.MakePlayerFall();
		PLAYER.jumpSoundOn = true;
	}
	 
	if (PS.BeadData(PLAYER.X, PLAYER.Y) === "goal") //go to next level if current data is goal
	{
		GAME.next_level = true;
		PS.AudioPlay("l_hchord_c5");
		PS.AudioPlay("l_hchord_e5");
		PS.AudioPlay("l_hchord_g5");
	}
	 
	
	if (PLAYER.Y < 15){
		if (PS.BeadData(PLAYER.X, PLAYER.Y + 1) === "ground")
			PLAYER.jumpSoundOn = false;
	}
	
	if (PLAYER.jumpSoundOn){ //play the jump sound effect when its ready
		PLAYER.UpSound();
	}
	
	/*
	 The following is an attempted bug fix that went horribly wrong
	 
	 if ( UTIL.CheckData("goal") )
	{
		PS.BeadColor(UTIL.X, UTIL.Y, GAME.GOAL_COLOR)
	}*/
	
	if (GAME.level_count === 12) //disable movement on the final level
		{
		PS.Clock(0);
		PLAYER.COLOR = 0x0E0A0F;
		}
	//PLAYER.AbsorbColor(); //If we're in a block that can be absorbed, we absorb it and change the player's color
};
